"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const create_package_1 = require("./lib/create-package");
const normalize_1 = require("./lib/normalize");
const devkit_1 = require("@nx/devkit");
const upload_package_1 = require("./lib/upload-package");
const update_function_1 = require("./lib/update-function");
const delete_package_1 = require("./lib/delete-package");
const update_cloudfront_lambda_association_1 = require("./lib/update-cloudfront-lambda-association");
const credential_providers_1 = require("@aws-sdk/credential-providers");
function runExecutor(_options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const options = (0, normalize_1.normalizeOptions)(_options, context);
            devkit_1.logger.log(` 📦 Creating the package at ${options.packageFilePath}`);
            yield (0, create_package_1.createPackage)(options);
            if (options.isAssumeRole) {
                devkit_1.logger.log(` 👤 Assuming role ${options.assumeRoleArn}`);
                options.credentials = (0, credential_providers_1.fromTemporaryCredentials)({
                    params: {
                        RoleArn: options.assumeRoleArn,
                    },
                });
            }
            if (options.isUploadToS3) {
                devkit_1.logger.log(` 🚀 Uploading the package to S3 bucket ${options.s3Bucket}`);
                yield (0, upload_package_1.uploadPackage)(options);
            }
            devkit_1.logger.log(` Updating the lambda function ${options.functionName}`);
            const { Version } = yield (0, update_function_1.updateFunction)(options);
            if (options.deleteLocalPackage) {
                devkit_1.logger.log(` Deleting the local package ${options.packageFilePath}`);
                yield (0, delete_package_1.deletePackageFile)(options);
            }
            if (options.isLambdaEdge) {
                devkit_1.logger.log(` Updating the CloudFront distribution ${options.cloudFrontDistributionId}`);
                yield (0, update_cloudfront_lambda_association_1.updateCloudFrontLambdaAssociation)(Object.assign(Object.assign({}, options), { version: Version }));
            }
            return {
                success: true,
            };
        }
        catch (error) {
            devkit_1.logger.error(error);
            return {
                success: false,
                error: error.message,
            };
        }
    });
}
exports.default = runExecutor;
//# sourceMappingURL=executor.js.map