"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPackage = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const archiver = require("archiver");
/**
 * Creates a package from the build directory.
 * @param options The options for creating the package.
 * @returns A promise that resolves when the package is created.
 * @throws An error if the build directory does not exist.
 * @throws An error if there are errors with archiving.
 */
function createPackage(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!(0, fs_1.existsSync)(options.buildDirectoryPath)) {
            throw new Error(`The build directory does not exist: ${options.buildDirectoryPath}`);
        }
        const zipFileStream = (0, fs_1.createWriteStream)(options.packageFilePath);
        const archive = archiver('zip', {
            zlib: { level: options.compressionLevel },
        });
        archive.pipe(zipFileStream);
        archive.directory(options.buildDirectoryPath, 'src');
        archive.finalize();
        return new Promise((resolve, reject) => {
            zipFileStream.on('close', () => {
                resolve();
            });
            archive.on('error', (err) => {
                reject(new Error(`Failed to create the package: ${err}`));
            });
        });
    });
}
exports.createPackage = createPackage;
//# sourceMappingURL=create-package.js.map