"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateCloudFrontLambdaAssociation = void 0;
const tslib_1 = require("tslib");
const client_cloudfront_1 = require("@aws-sdk/client-cloudfront");
const client_lambda_1 = require("@aws-sdk/client-lambda");
function updateCloudFrontLambdaAssociation(options) {
    var _a, _b, _c;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const lambda = new client_lambda_1.Lambda({
            region: options.awsRegion,
            credentials: options.credentials,
        });
        // Wait for the lambda function to be active
        let isFunctionActive = false;
        while (!isFunctionActive) {
            try {
                const res = yield lambda.getFunction({
                    FunctionName: options.functionName,
                    Qualifier: options.version,
                });
                if (((_a = res.Configuration) === null || _a === void 0 ? void 0 : _a.State) === 'Active') {
                    isFunctionActive = true;
                }
            }
            catch (e) {
                /* empty */
            }
            yield new Promise((resolve) => setTimeout(resolve, 1000));
        }
        const cloudfront = new client_cloudfront_1.CloudFront({
            region: options.awsRegion,
            credentials: options.credentials,
        });
        const { DistributionConfig, ETag } = yield cloudfront.getDistributionConfig({
            Id: options.cloudFrontDistributionId,
        });
        const lambdaAssociations = (_c = (_b = DistributionConfig === null || DistributionConfig === void 0 ? void 0 : DistributionConfig.DefaultCacheBehavior) === null || _b === void 0 ? void 0 : _b.LambdaFunctionAssociations) === null || _c === void 0 ? void 0 : _c.Items;
        if (!lambdaAssociations) {
            throw new Error('No lambda associations found');
        }
        const lambdaAssociationIdx = lambdaAssociations.findIndex((item) => item.EventType === options.cloudFrontEventType);
        if (lambdaAssociationIdx === -1) {
            throw new Error(`No ${options.cloudFrontEventType} lambda association found`);
        }
        const previousArn = lambdaAssociations[lambdaAssociationIdx].LambdaFunctionARN;
        lambdaAssociations[lambdaAssociationIdx].LambdaFunctionARN =
            previousArn.replace(/[0-9]+$/, options.version);
        return cloudfront.updateDistribution({
            Id: options.cloudFrontDistributionId,
            DistributionConfig,
            IfMatch: ETag,
        });
    });
}
exports.updateCloudFrontLambdaAssociation = updateCloudFrontLambdaAssociation;
//# sourceMappingURL=update-cloudfront-lambda-association.js.map